#ifndef __CHEBY__TESTER_WR_REGS__H__
#define __CHEBY__TESTER_WR_REGS__H__
#define TESTER_WR_REGS_SIZE 8248

/* General status */
#define TESTER_WR_REGS_STATUS 0x2008UL
#define TESTER_WR_REGS_STATUS_TIME_VALID 0x1UL
#define TESTER_WR_REGS_STATUS_LINK_VALID 0x2UL

/* TAI from wr */
#define TESTER_WR_REGS_TM_TAI 0x2010UL

/* number of cycles (16Mhz) within the second */
#define TESTER_WR_REGS_TM_CYCLES 0x2018UL

/* absolute TAI (LSB) for interrupts */
#define TESTER_WR_REGS_START_TAI 0x201cUL

/* absolute cycles for interrupts */
#define TESTER_WR_REGS_START_CYCLES 0x2020UL

/* number of cycles between interrupts */
#define TESTER_WR_REGS_PERIOD_CYCLES 0x2024UL

/* number of interrupts to deliver */
#define TESTER_WR_REGS_TOTAL_COUNT 0x2028UL

/* number of interrupts delivered. */
#define TESTER_WR_REGS_CURRENT_COUNT 0x202cUL

/* the current number of interrupts must be written to ack the interrupt. */
#define TESTER_WR_REGS_ACK_INT 0x2030UL

/* number of interrupts successfully ack-ed; cleared at the start */
#define TESTER_WR_REGS_ACK_COUNT 0x2034UL

struct tester_wr_regs {

  /* padding to: 2050 words */
  uint32_t __padding_0[2050];
  /* [0x2008]: REG (ro) General status */
  uint32_t status;

  /* padding to: 2052 words */
  uint32_t __padding_1[1];

  /* [0x2010]: REG (ro) TAI from wr */
  uint64_t tm_tai;

  /* [0x2018]: REG (ro) number of cycles (16Mhz) within the second */
  uint32_t tm_cycles;

  /* [0x201c]: REG (rw) absolute TAI (LSB) for interrupts */
  uint32_t start_tai;

  /* [0x2020]: REG (rw) absolute cycles for interrupts */
  uint32_t start_cycles;

  /* [0x2024]: REG (rw) number of cycles between interrupts */
  uint32_t period_cycles;

  /* [0x2028]: REG (rw) number of interrupts to deliver */
  uint32_t total_count;

  /* [0x202c]: REG (ro) number of interrupts delivered. */
  uint32_t current_count;

  /* [0x2030]: REG (wo) the current number of interrupts must be written to ack the interrupt. */
  uint32_t ack_int;

  /* [0x2034]: REG (ro) number of interrupts successfully ack-ed; cleared at the start */
  uint32_t ack_count;
};

#endif /* __CHEBY__TESTER_WR_REGS__H__ */
